Module connectivity

Module connectivity 

Network connectivity and peering operations for Pro subscriptions

This module manages advanced networking features for Redis Cloud Pro subscriptions, including VPC peering, AWS Transit Gateway attachments, GCP Private Service Connect, AWS PrivateLink, and other cloud-native networking integrations.

Supported Connectivity Types

  • VPC Peering: Direct peering between Redis Cloud VPC and your VPC
  • Transit Gateway: AWS Transit Gateway attachments for hub-and-spoke topologies
  • Private Service Connect: GCP Private Service Connect for private endpoints
  • PrivateLink: AWS PrivateLink for secure private connectivity

Module Organization

The connectivity features are split into four specialized modules:

  • vpc_peering - VPC peering operations for AWS, GCP, and Azure
  • psc - Google Cloud Private Service Connect endpoints
  • transit_gateway - AWS Transit Gateway attachments
  • private_link - AWS PrivateLink connectivity

Re-exports

pub use private_link::PrivateLinkHandler;
pub use private_link::PrincipalType;
pub use private_link::PrivateLinkActiveActiveConnectionsDisassociateRequest;
pub use private_link::PrivateLinkAddPrincipalRequest;
pub use private_link::PrivateLinkConnectionDisassociate;
pub use private_link::PrivateLinkConnectionsDisassociateRequest;
pub use private_link::PrivateLinkCreateRequest;
pub use private_link::PrivateLinkRemovePrincipalRequest;
pub use psc::PscHandler;
pub use transit_gateway::TransitGatewayHandler;
pub use vpc_peering::VpcPeeringHandler;
pub use psc::PscEndpointUpdateRequest;
pub use transit_gateway::Cidr;
pub use transit_gateway::TgwAttachmentRequest;
pub use transit_gateway::TgwUpdateCidrsRequest;
pub use vpc_peering::ActiveActiveVpcPeering;
pub use vpc_peering::ActiveActiveVpcPeeringCreateRequest;
pub use vpc_peering::ActiveActiveVpcPeeringList;
pub use vpc_peering::ActiveActiveVpcRegion;
pub use vpc_peering::VpcCidr;
pub use vpc_peering::VpcPeering;
pub use vpc_peering::VpcPeeringCreateBaseRequest;
pub use vpc_peering::VpcPeeringCreateRequest;
pub use vpc_peering::VpcPeeringUpdateAwsRequest;
pub use vpc_peering::VpcPeeringUpdateRequest;

Modules

private_link
AWS PrivateLink connectivity operations
psc
Google Cloud Private Service Connect (PSC) operations.
transit_gateway
AWS Transit Gateway (TGW) attachment operations.
vpc_peering
VPC peering operations for AWS and GCP Pro subscriptions.

Structs

ConnectivityHandler
Unified connectivity handler combining VPC Peering, PSC, and Transit Gateway operations.