pub struct DatabaseBackupRequest {
pub subscription_id: Option<i32>,
pub database_id: Option<i32>,
pub region_name: Option<String>,
pub adhoc_backup_path: Option<String>,
pub command_type: Option<String>,
}Expand description
Database backup request message
Example
use redis_cloud::flexible::databases::DatabaseBackupRequest;
let request = DatabaseBackupRequest::builder()
.region_name("us-east-1")
.build();Fields
subscription_id: Option<i32>Subscription ID being updated. Server-populated from the path.
database_id: Option<i32>Database ID being updated. Server-populated from the path.
region_name: Option<String>Required for Active-Active databases. Name of the cloud provider region to back up. When backing up an Active-Active database, you must back up each region separately.
adhoc_backup_path: Option<String>Optional. Manually backs up data to this location, instead of the set ‘remoteBackup’ location.
command_type: Option<String>Read-only on the response; populated by the server with the
operation type (e.g. "BACKUP_DATABASE").
Implementations
Sourceimpl DatabaseBackupRequest
impl DatabaseBackupRequest
Sourcepub fn builder() -> DatabaseBackupRequestBuilder<((), (), (), (), ())>
pub fn builder() -> DatabaseBackupRequestBuilder<((), (), (), (), ())>
Create a builder for building DatabaseBackupRequest.
On the builder, call .subscription_id(...)(optional), .database_id(...)(optional), .region_name(...)(optional), .adhoc_backup_path(...)(optional), .command_type(...)(optional) to set the values of the fields.
Finally, call .build() to create the instance of DatabaseBackupRequest.