pub struct CustomerManagedKeyAccessDetails {
pub redis_service_account: Option<String>,
pub google_predefined_roles: Option<Vec<String>>,
pub google_custom_permissions: Option<Vec<String>>,
pub redis_iam_role: Option<String>,
pub required_key_policy_statements: Option<HashMap<String, Value>>,
pub deletion_grace_period_options: Option<Vec<String>>,
}Expand description
Configuration regarding customer managed persistent storage encryption
Fields
redis_service_account: Option<String>Redis service account that requires CMK access (GCP).
google_predefined_roles: Option<Vec<String>>GCP predefined roles the service account must be granted.
google_custom_permissions: Option<Vec<String>>GCP custom permissions required on the customer managed key.
redis_iam_role: Option<String>AWS IAM role used by Redis to access the customer managed key.
required_key_policy_statements: Option<HashMap<String, Value>>AWS KMS key-policy statements required for Redis to use the CMK.
deletion_grace_period_options: Option<Vec<String>>Supported deletion grace period options for the CMK.